@@ -251,7 +251,7 @@ class FLASH(nn.Module):
         j - sequence dimension (target)
         """
 
-        n, device, g = x.shape[-2], x.device, self.group_size
+        b, n, device, g = x.shape[0], x.shape[-2], x.device, self.group_size
 
         # prenorm
 
@@ -283,8 +283,8 @@ class FLASH(nn.Module):
         if padding > 0:
             quad_q, quad_k, lin_q, lin_k, v = map(lambda t: F.pad(t, (0, 0, 0, padding), value = 0.), (quad_q, quad_k, lin_q, lin_k, v))
 
-            if exists(mask):
-                mask = F.pad(mask, (0, padding), value = False)
+            mask = default(mask, torch.ones((b, n), device = device, dtype = torch.bool))
+            mask = F.pad(mask, (0, padding), value = False)
 
         # group along sequence
 
@@ -370,7 +370,7 @@ class FLASHTransformer(nn.Module):
         self.rel_pos_bias = T5RelativePositionBias(query_key_dim ** 0.5, causal = causal)
 
         rotary_pos_emb = RotaryEmbedding(dim = min(32, query_key_dim))
-        self.layers = [FLASH(dim = dim, group_size = group_size, query_key_dim = query_key_dim, expansion_factor = expansion_factor, causal = causal, dropout = attn_dropout, rotary_pos_emb = rotary_pos_emb, norm_klass = norm_klass) for _ in range(depth)]
+        self.layers = nn.ModuleList([FLASH(dim = dim, group_size = group_size, query_key_dim = query_key_dim, expansion_factor = expansion_factor, causal = causal, dropout = attn_dropout, rotary_pos_emb = rotary_pos_emb, norm_klass = norm_klass) for _ in range(depth)])
 
         self.to_logits = nn.Sequential(
             nn.LayerNorm(dim),
